The entry points for the two template repeater examples are template_repeater.ui
and flow_template_repeater.ui.  Before running either example, start the magnet_ioc.py
script in another terminal.  Note: magnet_ioc.py requires the 'caproto' module, and
is only compatible with Python>=3.6.